@@ -7,23 +7,35 @@ import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
 import plotly.express as px
-from matplotlib.ticker import LogFormatter
+from matplotlib.ticker import LogFormatter, MaxNLocator
 from io import BytesIO
 
 
-def report_extraction(model, df, report_statistics):
+def report_extraction(model, df, report_statistics, output_folder, shader=False) -> None:
     """
-    Generate a detailed HTML report summarizing the kcat extraction results
-    with separate tables for extracted data and EC issues, and visualizations.
+    Generates a detailed HTML report summarizing kcat extraction results from a metabolic model.
+
+    Parameters: 
+        model (cobra.Model): The metabolic model object containing reactions, metabolites, and genes.
+        df (pandas.DataFrame): DataFrame containing data from the run_extraction function.
+        report_statistics (dict): Dictionary with statistics about EC code assignment and extraction issues.
+        output_folder (str): Path to the output folder where the report will be saved.
+        shader (bool, optional): If True, includes a shader canvas background in the report. Default is False.
+
+    Returns: 
+        None: The function saves the generated HTML report to 'reports/extract_kcat_report.html'. 
     """
     # Model statistics
     nb_model_reactions = len(model.reactions)
     nb_model_metabolites = len(model.metabolites)
     nb_model_genes = len(model.genes)
+    rxn_with_ec = 0
     unique_ec_codes = []
+
     for rxn in model.reactions:
         ec_code = rxn.annotation.get('ec-code')
         if ec_code:
+            rxn_with_ec += 1
             if isinstance(ec_code, str):
                 ec_code = [ec_code.strip()]
             elif isinstance(ec_code, list):
@@ -31,26 +43,33 @@ def report_extraction(model, df, report_statistics):
             else:
                 ec_code = []
             unique_ec_codes.extend(ec_code)
+    
     nb_model_ec_codes = len(set(unique_ec_codes))
 
     # Kcat statistics
     nb_reactions = df['rxn'].nunique()
-    nb_ec_codes = df['ec_code'].nunique()
+    nb_ec_codes = df.loc[df["warning_ec"].fillna("") == "", "ec_code"].nunique()
 
-    nb_ec_codes_transferred = report_statistics.get('transferred_ec_codes', 0)
-    nb_ec_codes_incomplete = report_statistics.get('incomplete_ec_codes', 0)
-    nb_reactions_dropped = report_statistics.get('nb_of_reactions_due_to_unconsistent_ec', 0)
-    nb_lines_dropped = report_statistics.get('nb_of_lines_dropped_due_to_unconsistent_ec', 0)
+
+    # nb_missing_ec = report_statistics.get('nb_missing_ec', np.nan)
+    nb_incomplete_ec = report_statistics.get('nb_incomplete_ec', np.nan)
+    nb_transferred_ec = report_statistics.get('nb_transferred_ec', np.nan)
+    nb_missing_gpr = report_statistics.get('nb_missing_gpr', np.nan)
+    nb_missing_catalytic_enzyme = report_statistics.get('nb_missing_catalytic_enzyme', 0)
+    # nb_multiple_catalytic_enzymes = report_statistics.get('nb_multiple_catalytic_enzymes', np.nan)
+    nb_of_lines_dropped_no_ec_no_enzyme = report_statistics.get('nb_of_lines_dropped_no_ec_no_enzyme', np.nan)
+    nb_of_reactions_dropped_no_ec_no_enzyme = report_statistics.get('nb_of_reactions_dropped_no_ec_no_enzyme', np.nan)
 
     rxn_coverage = 100.0 * nb_reactions / nb_model_reactions if nb_model_reactions else 0
+    # percent_ec_retrieved = 100.0 * nb_ec_codes / nb_model_ec_codes if nb_model_ec_codes else 0
 
-    percent_ec_retrieved = 100.0 * nb_ec_codes / nb_model_ec_codes if nb_model_ec_codes else 0
+    rxn_ec_coverage = 100.0 * rxn_with_ec / nb_model_reactions if nb_model_ec_codes else 0
 
     # Pie Chart
     pie_data = {
         "Retrieved": nb_ec_codes,
-        "Transferred": nb_ec_codes_transferred,
-        "Incomplete": nb_ec_codes_incomplete,
+        "Transferred": nb_transferred_ec, 
+        "Incomplete": nb_incomplete_ec,
     }
 
     pie_data = {k: v for k, v in pie_data.items() if v > 0}
@@ -63,7 +82,7 @@ def report_extraction(model, df, report_statistics):
     fig.update_traces(textinfo="percent+label", textfont_size=16)
     fig.update_layout(
         title="",
-        title_font=dict(size=20, color="black"),
+        title_font=dict(size=30, color="black"),
         showlegend=True
     )
 
@@ -125,7 +144,7 @@ def report_extraction(model, df, report_statistics):
                         <th>Visualization</th>
                     </tr>
                     <tr>
-                        <td>Reactions with EC info</td>
+                        <td>Reaction with k<sub>cat</sub> information</td>
                         <td>{nb_reactions} ({rxn_coverage:.1f}%)</td>
                         <td>
                             <div class="progress">
@@ -134,17 +153,17 @@ def report_extraction(model, df, report_statistics):
                         </td>
                     </tr>
                     <tr>
-                        <td>EC codes retrieved in KEGG</td>
-                        <td>{nb_ec_codes} ({percent_ec_retrieved:.1f}%)</td>
+                        <td>Reactions with EC information</td>
+                        <td>{rxn_with_ec} ({rxn_ec_coverage:.1f}%)</td>
                         <td>
                             <div class="progress">
-                                <div class="progress-bar-table" style="width:{percent_ec_retrieved}%;"></div>
+                                <div class="progress-bar-table" style="width:{rxn_ec_coverage}%;"></div>
                             </div>
                         </td>
                     </tr>
                     <tr>
-                        <td>Total rows in output (Rxn - EC - Enzyme - Substrate)</td>
-                        <td>{len(df) - 1}</td>
+                        <td>Total k<sub>cat</sub> in output</td>
+                        <td>{len(df)}</td>
                         <td>-</td>
                     </tr>
                 </table>
@@ -152,7 +171,27 @@ def report_extraction(model, df, report_statistics):
 
             <!-- EC Issues Table -->
             <div class="card">
-                <h2>Issues in EC Assignment</h2>
+                <h2>Quality Control</h2>
+
+                <p style="text-align: justify">
+                    During the extraction process, several issues may arise that can impact the 
+                    quality of the retrieved k<sub>cat</sub> data.
+                    <br>
+                    When an EC number is incomplete or has been transferred, WILDkCAT performs the 
+                    retrieval based only on the available enzyme information. Such cases are indicated as 
+                    'incomplete' or 'transferred' in the 'warning_ec' column. 
+                    These situations reduce the likelihood of finding alternative k<sub>cat</sub> values.
+                    <br>
+                    Additionally, WILDkCAT attempts to identify the catalytic enzyme associated with 
+                    each reaction. If no Gene–Protein–Reaction rule is available, or if the catalytic 
+                    enzyme cannot be found via the UniProt API, the entry is labeled as 
+                    'none' in the 'warning_enz' column.
+                    <br>
+                    If both the EC number and the catalytic enzyme information are missing for a given 
+                    reaction, the corresponding row is removed due to insufficient information to assign 
+                    a k<sub>cat</sub> value.
+                </p>
+
                 <table>
                     <tr>
                         <th>Cases</th>
@@ -160,19 +199,23 @@ def report_extraction(model, df, report_statistics):
                     </tr>
                     <tr>
                         <td>Transferred EC codes</td>
-                        <td>{nb_ec_codes_transferred}</td>
+                        <td>{nb_transferred_ec}</td>
                     </tr>
                     <tr>
                         <td>Incomplete EC codes</td>
-                        <td>{nb_ec_codes_incomplete}</td>
+                        <td>{nb_incomplete_ec}</td>
                     </tr>
                     <tr>
-                        <td>Number of reactions dropped due to inconsistent EC codes</td>
-                        <td>{nb_reactions_dropped}</td>
+                        <td>Number of reactions without catalytic enzyme</td>
+                        <td>{nb_missing_gpr + nb_missing_catalytic_enzyme}</td>
                     </tr>
                     <tr>
-                        <td>Number of k<sub>cat</sub> values dropped due to inconsistent EC codes</td>
-                        <td>{nb_lines_dropped}</td>
+                        <td>Number of reactions dropped due to inconsistent or absent EC codes and enzymes</td>
+                        <td>{nb_of_reactions_dropped_no_ec_no_enzyme}</td>
+                    </tr>
+                    <tr>
+                        <td>Number of k<sub>cat</sub> values dropped due to inconsistent or absent EC codes and enzymes</td>
+                        <td>{nb_of_lines_dropped_no_ec_no_enzyme}</td>
                     </tr>
                 </table>
             </div>
@@ -185,26 +228,36 @@ def report_extraction(model, df, report_statistics):
         </div>
 
         <footer>WILDkCAT</footer>
+    """
+    if shader:
+        html += report_shader()
+    else: 
+        html += report_simple()
+    html += """
     </body>
-    {report_shader()}
     </html>
     """
 
     # Save report
-    os.makedirs("reports", exist_ok=True)
-    report_path = "reports/extract_kcat_report.html"
+    os.makedirs(os.path.join(output_folder, "reports"), exist_ok=True)
+    report_path = os.path.join(output_folder, "reports/extract_report.html")
     with open(report_path, "w", encoding="utf-8") as f:
         f.write(html)
     logging.info(f"HTML report saved to '{report_path}'")
 
 
-def report_retrieval(df):
+def report_retrieval(df, output_folder, parameters, shader=False) -> None:
     """
     Generate a styled HTML report summarizing the kcat matching results,
     including kcat value distribution and matching score repartition.
 
     Parameters:
-        df (pd.DataFrame): Must contain ['kcat', 'matching_score', ...].
+        df (pd.DataFrame): DataFrame containing data from the run_retrieval function.
+        output_folder (str): Path to the output folder where the report will be saved.
+        shader (bool, optional): If True, includes a shader canvas background in the report. Default is False.
+
+    Returns:
+        None: The function saves the generated HTML report to 'reports/retrieve_kcat_report.html'.
     """
     # Ensure numeric kcat values to avoid TypeError on comparisons
     kcat_values = pd.to_numeric(df['kcat'], errors='coerce').dropna()
@@ -212,13 +265,12 @@ def report_retrieval(df):
     # Only use scores present in the data
     present_scores = sorted(df['matching_score'].dropna().unique())
     score_counts = df['matching_score'].value_counts().reindex(present_scores, fill_value=0)
-    total = len(df) - 1
+    total = len(df)
     matched = len(kcat_values)
     match_percent = matched / total * 100 if total else 0
     score_percent = (score_counts / total * 100).round(2) if total else pd.Series(0, index=present_scores)
 
-    # Distinct colors for each score (up to 12, then cycle)
-    # Gradient colors from green (best score) to red (worst score)
+    # Gradient colors from green (best score) to red (worst score) # TODO: It could be better to create the scale dynamically based on present scores
     distinct_colors = [
         "#27ae60",
         "#43b76e",
@@ -227,6 +279,7 @@ def report_retrieval(df):
         "#98d298",
         "#b5dbb6",
         "#d1e4c4",
+        "#e8e9b9",
         "#f1e9b6",
         "#f7d97c",
         "#f9c74f",
@@ -234,9 +287,9 @@ def report_retrieval(df):
         "#f3722c",
         "#e67e22",
         "#e74c3c",
+        "#d35400",
         "#c0392b",
         "#a93226",
-        "#922b21",
         "#7b241c"
     ]
 
@@ -245,6 +298,13 @@ def report_retrieval(df):
         return distinct_colors[idx % len(distinct_colors)]
 
     generated_time = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+    
+    # Parameters
+    temp = parameters.get('Temperature')
+    formatted_temp = f"{temp[0]} - {temp[1]}"
+
+    ph = parameters.get('pH')
+    formatted_ph = f"{ph[0]} - {ph[1]}"
 
     # Histogram with stacked bars for scores
     kcat_hist_base64 = ""
@@ -253,24 +313,52 @@ def report_retrieval(df):
         max_exp = int(np.ceil(np.log10(kcat_values.max())))
         bins = np.logspace(min_exp, max_exp, num=40)
 
-        fig, ax = plt.subplots(figsize=(10, 6))
+        # Rm empty score groups (16 - 17)
+        hist_data = []
+        valid_scores = []
+        for score in present_scores:
+            vals = pd.to_numeric(df[df['matching_score'] == score]['kcat'], errors='coerce')
+            vals = vals[vals.notna()]
+            if not vals.empty:
+                hist_data.append(vals)
+                valid_scores.append(score)
+
+        fig, ax = plt.subplots(figsize=(12, 6))
         
         # Stacked histogram by score
-        
-        hist_data = [pd.to_numeric(df[df['matching_score'] == score]['kcat'], errors='coerce').dropna() for score in present_scores]
         ax.hist(hist_data, bins=bins, stacked=True, 
-                color=[score_color(s) for s in present_scores], label=[f"Score {s}" for s in present_scores], edgecolor='white')
+                color=[score_color(s) for s in valid_scores],
+                label=[f"{s}" for s in valid_scores],
+                edgecolor='white')
         
         ax.set_xscale('log')
         ax.set_xlim([10**min_exp / 1.5, 10**max_exp * 1.5])
         ax.xaxis.set_major_formatter(LogFormatter(10))
+        ax.yaxis.set_major_locator(MaxNLocator(integer=True))
 
         ax.set_xlabel("kcat (s⁻¹)", fontsize=12)
         ax.set_ylabel("Count", fontsize=12)
         ax.set_title(f"", fontsize=13)
-        ax.legend(title="Matching Score", fontsize=12)
         
-        plt.tight_layout()
+        ax.legend(
+            title="Matching Score", 
+            fontsize=10, 
+            title_fontsize=11,
+            loc='center left', 
+            bbox_to_anchor=(1, 0.5),
+            frameon=False
+        )
+        
+        # Style
+        ax.spines['top'].set_visible(False)
+        ax.spines['right'].set_visible(False)
+        ax.spines['left'].set_color('#444444')
+        ax.spines['bottom'].set_color('#444444')
+
+        ax.grid(True, which='major', axis='y', linestyle='--', linewidth=0.6, alpha=0.4)
+        ax.grid(False, which='major', axis='x') 
+
+        plt.tight_layout(rect=[0, 0, 0.85, 1])
         buf = io.BytesIO()
         plt.savefig(buf, format='png', bbox_inches='tight')
         plt.close(fig)
@@ -310,6 +398,30 @@ def report_retrieval(df):
                 </div>
             </div>
 
+            <div class="card">
+                <div class="card">
+                <h2>Parameters</h2>
+                <div class="stats-grid">
+                    <div class="stat-box">
+                        <h3>{parameters.get('Organism')}</h3>
+                        <p>Organism name</p>
+                    </div>
+                    <div class="stat-box">
+                        <h3>{formatted_ph}</h3>
+                        <p>pH range</p>
+                    </div>
+                    <div class="stat-box">
+                        <h3>{formatted_temp}</h3>
+                        <p>Temperature range</p>
+                    </div>
+                     <div class="stat-box">
+                        <h3>{parameters.get('database').capitalize()}</h3>
+                        <p>Database(s)</p>
+                    </div>
+                </div>
+            </div>
+            </div>
+
             <div class="card">
                 <h2>Matching Score Distribution</h2>
                 <div class="progress-stacked">
@@ -368,7 +480,7 @@ def report_retrieval(df):
                 <h2>Matching Score</h2>
                 <p>
                     The matching score evaluates how well a candidate k<sub>cat</sub> entry fits the query enzyme and conditions. 
-                    A lower score indicates a better match (0 = best possible, 15 = no match).
+                    A lower score indicates a better match (0 = Best possible, 17 = No match).
                 </p>
                 <h3>Scoring process:</h3>
                 <ul>
@@ -381,7 +493,7 @@ def report_retrieval(df):
                         if possible, adjust kcat values using the Arrhenius equation.</li>
                 </ul>
 
-                <h3>Score breakdown (default penalties):</h3>
+                <h3>Score breakdown:</h3>
                 <table border="1" cellpadding="6" cellspacing="0" style="border-collapse: collapse; text-align: left;">
                     <tr>
                         <th>Criterion</th>
@@ -389,11 +501,11 @@ def report_retrieval(df):
                     </tr>
                     <tr>
                         <td>Substrate mismatch</td>
-                        <td>+3</td>
+                        <td>+4</td>
                     </tr>
                     <tr>
                         <td>Catalytic enzyme mismatch</td>
-                        <td>+2</td>
+                        <td>+3</td>
                     </tr>
                     <tr>
                         <td>Organism mismatch</td>
@@ -424,38 +536,61 @@ def report_retrieval(df):
                 <p>
                     Candidates are then ranked by:
                     <ol>
-                        <li>Lowest total score</li>
+                        <li>Lowest penalty-score</li>
                         <li>Highest sequence identity percentage to the target enzyme</li>
-                        <li>Adjusted k<sub>cat</sub> value (favoring the smallest value by default)</li>
+                        <li>Closest organism compared to the target organism.</li>
+                        <li>Adjusted k<sub>cat</sub> value (favoring the highest value by default)</li>
                     </ol>
+
+                <i>Please check the <a href="https://h-escoffier.github.io/WILDkCAT/explanation/explanation/#2-retrieve-experimental-kcat-values-from-brenda-andor-sabio-rk" target="_blank" rel="noopener noreferrer">documentation</a> for more details on the scoring system and the retrieval process.</i>
                 </p>
-                <p>
-                    The best candidate is the one with the lowest score after these checks. 
-                    If multiple candidates tie on score, sequence identity and k<sub>cat</sub> values break the tie.
+            </div>
+            
+            <div class="card">
+                <h2>Notes</h2>
+                <p style="text-align: justify">
+                    Please note that the number of rows may differ between the extraction and retrieval stages. 
+                    Indeed, when a single reaction–enzyme combination is associated with multiple EC numbers, WILDkCAT 
+                    automatically merges these rows after retrieval, keeping only the best entry according to the criteria 
+                    described above. The EC number of the selected kcat is stored in the 'ec_code' column, while all EC 
+                    numbers associated with the reaction are stored in the 'ec_codes' column.
                 </p>
             </div>
         </div>
 
         <footer>WILDkCAT</footer>
-    
-    {report_shader()}
+    """
+    if shader: 
+        html += report_shader()
+    else: 
+        html += report_simple()
+    html += """
     </body>
     </html>
     """
 
     # Save HTML
-    os.makedirs("reports", exist_ok=True)
-    report_path = f"reports/retrieve_kcat_report.html"
+    os.makedirs(os.path.join(output_folder, "reports"), exist_ok=True)
+    report_path = os.path.join(output_folder, "reports/retrieve_report.html")
     with open(report_path, "w", encoding="utf-8") as f:
         f.write(html)
 
     logging.info(f"HTML report saved to '{report_path}'")
 
 
-def report_prediction_input(catapro_df, report_statistics): 
-    
-    # TODO: Show the number of rows without any enzymes
+def report_prediction_input(catapro_df, report_statistics, output_folder, shader=False) -> None: 
+    """
+    Generate a detailed HTML report summarizing the kcat prediction input statistics.
 
+    Parameters:
+        catapro_df (pd.DataFrame): DataFrame containing the CataPro input data.
+        report_statistics (dict): Dictionary with statistics about the prediction input.
+        output_folder (str): Path to the output folder where the report will be saved.
+        shader (bool, optional): If True, includes a shader canvas background in the report. Default is False.
+
+    Returns:
+        None: The function saves the generated HTML report to 'reports/predict_kcat_report.html'.
+    """
     # CataPro Statistics 
     total_catapro_entries = len(catapro_df) - 1
 
@@ -578,22 +713,34 @@ def report_prediction_input(catapro_df, report_statistics):
             </div>
 
     <footer>WILDkCAT</footer>
-    {report_shader()}
+    """
+    if shader:
+        html += report_shader()
+    else: 
+        html += report_simple()
+    html += """
     </body>
     </html>
     """
 
     # Save report
-    os.makedirs("reports", exist_ok=True)
-    report_path = "reports/predict_kcat_report.html"
+    os.makedirs(os.path.join(output_folder, "reports"), exist_ok=True)
+    report_path = os.path.join(output_folder, "reports/predict_report.html")
     with open(report_path, "w", encoding="utf-8") as f:
         f.write(html)
     logging.info(f"HTML report saved to '{report_path}'")
 
 
-def report_final(model, final_df):
+def report_final(model, final_df, output_folder, shader=False) -> None:
     """
-    Generate a full HTML report summarizing predicted vs. source kcat values.
+    Generate a full HTML report summarizing retrieval results, including kcat distributions and coverage.
+
+    Parameters:
+        model (cobra.Model): The metabolic model object containing reactions, metabolites, and genes.
+        final_df (pd.DataFrame): DataFrame containing the final kcat assignments from run_prediction_part2 function
+        
+    Returns: 
+        None: The function saves the generated HTML report to 'reports/general_report.html'.
     """
     # Model information 
     nb_model_reactions = len(model.reactions)
@@ -602,7 +749,7 @@ def report_final(model, final_df):
 
 
     df = final_df.copy()
-    df["kcat_db"] = df["kcat_db"].fillna("Unknown")
+    df["db"] = df["db"].fillna("Unknown")
     generated_time = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
 
     # Utility to convert matplotlib figures to base64 <img>
@@ -637,91 +784,69 @@ def report_final(model, final_df):
             sources = valid_df[source].unique()
             grouped_values = [valid_df.loc[valid_df[source] == src, column_name] for src in sources]
 
-            # Colors from seaborn palette
             # Fixed color mapping
             color_map = {
-                "brenda": "#55bb55",   # green
-                "sabio_rk": "#2277cc", # blue
-                "catapro": "#eedd00",  # yellow
-                "Unknown": "#dddddd"   # gray
+                "brenda": "#55bb55",   
+                "sabio_rk": "#2277cc", 
+                "catapro": "#eedd00",  
+                "Unknown": "#dddddd" 
             }
-            colors = [color_map.get(src, "#999999") for src in sources]  # fallback gray
+
+            label_map = {
+                "brenda": "Brenda",
+                "sabio_rk": "Sabio-RK",
+                "catapro": "CataPro",
+                "Unknown": "Unknown"
+            }
+
+            sources = [src for src in sources if src in valid_df[source].unique()]
+            colors = [color_map.get(src, "#999999") for src in sources]
 
             # Plot
-            fig, ax = plt.subplots(figsize=(10, 6))
+            fig, ax = plt.subplots(figsize=(12, 6))
             ax.hist(grouped_values, bins=bins, stacked=True,
-                    color=colors, label=sources, edgecolor="white", linewidth=0.7)
-
-            ax.set_xscale("log")
-            ax.set_xlim([10**min_exp / 1.5, 10**max_exp * 1.5])
-            ax.xaxis.set_major_formatter(LogFormatter(10))
-
-            ax.set_xlabel("kcat (s⁻¹)", fontsize=12)
-            ax.set_ylabel("Count", fontsize=12)
-            ax.set_title(f"{title} (n={matched}, {match_percent:.1f}%)", fontsize=13)
-            ax.legend(title="Source")
-
-            return fig_to_base64(fig)
-
-        return "<p>No valid values available for plotting.</p>"
-    
-
-    def plot_kcat_distribution(column_name, title):
-        df[column_name] = pd.to_numeric(df[column_name], errors='coerce')
-        kcat_values = df[column_name].dropna()
-
-        total = len(df)
-        matched = len(kcat_values)
-        match_percent = matched / total * 100 if total else 0
-
-        if not kcat_values.empty:
-            min_exp = int(np.floor(np.log10(max(1e-6, kcat_values.min()))))
-            max_exp = int(np.ceil(np.log10(kcat_values.max())))
-            bins = np.logspace(min_exp, max_exp, num=40)
-
-            fig, ax = plt.subplots(figsize=(10, 6))
-            ax.hist(kcat_values, bins=bins, color="#2277cc",
+                    color=colors, label=[label_map[s] for s in sources],
                     edgecolor="white", linewidth=0.7)
 
             ax.set_xscale("log")
             ax.set_xlim([10**min_exp / 1.5, 10**max_exp * 1.5])
             ax.xaxis.set_major_formatter(LogFormatter(10))
+            ax.yaxis.set_major_locator(MaxNLocator(integer=True))
 
             ax.set_xlabel("kcat (s⁻¹)", fontsize=12)
             ax.set_ylabel("Count", fontsize=12)
             ax.set_title(f"{title} (n={matched}, {match_percent:.1f}%)", fontsize=13)
 
+            ax.legend(
+                title="Source", 
+                fontsize=10, 
+                title_fontsize=11,
+                loc='center left', 
+                bbox_to_anchor=(1, 0.5),
+                frameon=False
+            )
+
+            # Style
+            ax.spines['top'].set_visible(False)
+            ax.spines['right'].set_visible(False)
+            ax.spines['left'].set_color('#444444')
+            ax.spines['bottom'].set_color('#444444')
+
+            ax.grid(True, which='major', axis='y', linestyle='--', linewidth=0.6, alpha=0.4)
+            ax.grid(False, which='major', axis='x') 
+            
+            plt.tight_layout(rect=[0, 0, 0.85, 1])
+
             return fig_to_base64(fig)
+
         return "<p>No valid values available for plotting.</p>"
-
-    img_source = plot_kcat_distribution_stacked(
-        'kcat_source', "Experimental kcat distribution", "kcat_source_db"
-    )
-    img_pred = plot_kcat_distribution(
-        'catapro_predicted_kcat_s', "Predicted kcat distribution"
-    )
+    
     img_final = plot_kcat_distribution_stacked(
-        'kcat', "kcat distribution", "kcat_db"
+        'kcat', "Kcat Distribution", "db"
     )
 
-    # Difference boxplot
-    if "kcat_source" in df.columns and "catapro_predicted_kcat_s" in df.columns:
-        df["kcat_diff"] = df["catapro_predicted_kcat_s"] - df["kcat_source"]
-        fig, ax = plt.subplots(figsize=(8, 5))
-        df.boxplot(column="kcat_diff", by="matching_score", grid=False,
-                   boxprops=dict(color="#2277cc"), medianprops=dict(color="black"), ax=ax)
-        ax.set_yscale("symlog")
-        ax.set_ylabel("Difference (Predicted - Source kcat, s⁻¹)")
-        ax.set_xlabel("Matching Score")
-        ax.set_title("Difference of retrieved vs predicted kcat")
-        plt.suptitle("")
-        ax.axhline(0, color="#cc4455", linestyle="--", linewidth=1)
-        img_diff = fig_to_base64(fig)
-    else:
-        img_diff = "<p>Required columns missing for difference plot.</p>"
-
     # Coverage
-    db_counts = df["kcat_db"].fillna("Unknown").value_counts()
+    db_counts = df["db"].fillna("Unknown").value_counts()
     total_db = db_counts.sum()
 
     colors = {
@@ -759,9 +884,9 @@ def report_final(model, final_df):
     # Statistics 
     grouped = df.groupby("rxn")
     rxns_with_kcat = grouped["kcat"].apply(lambda x: x.notna().any())
-    nb_rxn = grouped.ngroups
+    nb_reactions = df['rxn'].nunique()
     nb_rxn_with_kcat = rxns_with_kcat.sum()
-    coverage = nb_rxn_with_kcat / nb_rxn
+    coverage = nb_rxn_with_kcat / nb_reactions
     coverage_total = nb_rxn_with_kcat / nb_model_reactions
 
     kcat_values = df["kcat"].dropna()
@@ -790,13 +915,10 @@ def report_final(model, final_df):
         <div class="container">
             <div class="card">
                 <h2>Introduction</h2>
-                <p style="margin-bottom:20px; font-size:14px; color:#555; text-align: justify;">
+                <p style="text-align: justify;">
                     This report provides a summary of the performance of k<sub>cat</sub> value extraction, retrieval, and prediction for the specified metabolic model. 
                     It presents statistics on k<sub>cat</sub> values successfully retrieved, whether experimental or predicted.
                 </p>
-                <p style="margin-bottom:20px; font-size:14px; color:#555; text-align: justify;">
-                    The output file, containing the full list of k<sub>cat</sub> values associated with each reaction, are available as a tab-separated file (TSV) at the default output path: <code>output/model_name_kcat_full</code>.
-                </p>
             </div>
 
             <div class="card">
@@ -825,12 +947,12 @@ def report_final(model, final_df):
                 <h2 style="margin-bottom:10px;">Coverage</h2>
                 
                 <!-- Explanation -->
-                <p style="margin-bottom:20px; font-size:14px; color:#555; text-align: justify;">
+                <p style="text-align: justify;">
                     The coverage section reports the number of k<sub>cat</sub> values retrieved for the model and the number of reactions that have at least one 
-                    associated k<sub>cat</sub> value, whether experimental or predicted. This provides a measure of how extensively the model’s reactions are 
+                    associated k<sub>cat</sub> value. This provides a measure of how extensively the model’s reactions are 
                     annotated with kinetic data.
                 </p>
-                <p style="margin-bottom:20px; font-size:14px; color:#555; text-align: justify;">
+                <p style="text-align: justify;">
                     Higher coverage indicates that a larger fraction of reactions are constrained by k<sub>cat</sub> values, 
                     improving the accuracy and reliability of enzyme-constrained simulations.
                 </p>
@@ -841,8 +963,8 @@ def report_final(model, final_df):
                 <!-- Detailed stats -->
                 <table class="table" style="width:100%; border-spacing:0; border-collapse: collapse;">
                     <tbody>
-                        <tr>
-                            <td style="padding:8px 12px;">Reactions with EC information with at least one kcat values</td>
+                    <tr>
+                            <td style="padding:8px 12px;">Eligible-reactions with at least one kcat value</td>
                             <td style="padding:8px 12px;">{nb_rxn_with_kcat} ({coverage:.1%})</td>
                             <td style="width:40%;">
                                 <div class="progress" style="height:18px;">
@@ -853,7 +975,7 @@ def report_final(model, final_df):
                             </td>
                         </tr>
                         <tr>
-                            <td style="padding:8px 12px;">Reactions in the model with at least one kcat values</td>
+                            <td style="padding:8px 12px;">Model-wide reactions with at least one kcat value</td>
                             <td style="padding:8px 12px;">{nb_rxn_with_kcat} ({coverage_total:.1%})</td>
                             <td style="width:40%;">
                                 <div class="progress" style="height:18px;">
@@ -883,50 +1005,22 @@ def report_final(model, final_df):
                 <div class="img-section">
                     {img_final}
                 </div>
-                <p>
-                    Lorem Ipsum
-                </p>
-            </div>
-
-            <div class="card">
-                <h2>Experimental k<sub>cat</sub> Distribution</h2>
-                <div class="img-section">
-                    {img_source}
-                </div>
-                <p>
-                    Lorem Ipsum
-                </p>
-            </div>
-
-            <div class="card">
-                <h2>Predicted k<sub>cat</sub> Distribution</h2>
-                <div class="img-section">
-                    {img_pred}
-                </div>
-                <p>
-                    Lorem Ipsum
-                </p>
-            </div>
-
-            <div class="card">
-                <h2>Difference Analysis</h2>
-                <div class="img-section">
-                    {img_diff}
-                </div>
-                <p>
-                    Lorem Ipsum
-                </p>
             </div>
         </div>
 
         <footer>WILDkCAT</footer>
-    {report_shader()}
+    """
+    if shader:
+        html += report_shader()
+    else: 
+        html += report_simple()
+    html += """
     </body>
     </html>
     """
 
-    os.makedirs("reports", exist_ok=True)
-    report_path = "reports/general_report.html"
+    os.makedirs(os.path.join(output_folder, "reports"), exist_ok=True)
+    report_path = os.path.join(output_folder, "reports/general_report.html")
     with open(report_path, "w", encoding="utf-8") as f:
         f.write(html)
 
@@ -940,6 +1034,9 @@ def report_style():
     <style>
         body {
             font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
+            font-size: 1rem;
+            line-height: 1.7;
+            padding: 2rem 1.5rem;
             background-color: #f4f6f9;
             margin: 0;
             padding: 0;
@@ -990,6 +1087,9 @@ def report_style():
             font-size: 1.1rem;
             text-shadow: 0 1px 4px rgba(0,0,0,0.6);
         }
+        p {
+            margin-bottom: 1.2rem;
+        }
         .container {
             max-width: 1100px;
             margin: 30px auto;
@@ -1125,7 +1225,20 @@ def report_style():
     </style>
     """
 
-    
+
+def report_simple():
+    """Return HTML code for report background."""
+    return """
+    <style>
+        header {
+            background-color: #2980b9; /* simple blue background */
+            margin: 0;
+            padding: 0;
+        }
+    </style>
+    """
+
+
 def report_shader(): 
     """Return HTML and GLSL shader code for report background. Adapted from localthunk (https://localthunk.com)"""
     return """
