@@ -1,15 +1,14 @@
 import re 
+import logging
 import pandas as pd 
 import numpy as np
 from typing import Optional, Tuple, Dict, Any
 
 from ..utils.temperature import arrhenius_equation, calculate_ea
 from ..utils.organism import closest_enz, closest_taxonomy
-from ..utils.manage_warnings import logger_retrieval as logger
 
 
 # TODO: Limit the Ea to the same pH ? 
-# TODO: Tie computation could be speed up by computing only if there is different enzyme or organism
 
 
 # --- Main --- 
@@ -42,9 +41,9 @@ def find_best_match(kcat_dict, api_output, general_criteria) -> Tuple[float, Opt
     """
 
     # 1. Remove mutant enzymes
-    api_output = api_output[api_output["EnzymeVariant"].isin(['wildtype', None])]
+    api_output = api_output[api_output["EnzymeVariant"].isin(['wildtype', None])].copy()
     if api_output.empty:
-        return 14, None
+        return 16, None
 
     # 2. Compute score and adjust kcat if needed
     scores = []
@@ -55,13 +54,21 @@ def find_best_match(kcat_dict, api_output, general_criteria) -> Tuple[float, Opt
         score, arrhenius = compute_score(kcat_dict, candidate_dict, general_criteria, api_output)
         if arrhenius:
             kcat = arrhenius_equation(candidate_dict, api_output, general_criteria)
-            candidate_dict['value'] = kcat
-            candidate_dict['Temperature'] = np.mean(general_criteria["Temperature"])
+            if 10e-8 < kcat < 10e+8: 
+                candidate_dict['value'] = kcat
+                candidate_dict['Temperature'] = np.mean(general_criteria["Temperature"])
+            # If the kcat value calculated using the Arrhenius is aberrant, use the non correct value instead
+            else:
+                logging.warning(f"{candidate_dict.get('ECNumber')}: Corrected kcat ({kcat:.0f} s-1) is outside the expected range of 10e-8, 10e+8.")
+                temperature = float(candidate_dict['Temperature'])
+                if np.isnan(temperature): 
+                    score += 1
+                else: 
+                    score += 2
         scores.append(score)
         adjusted_kcats.append(candidate_dict.get('value', row['value']))
         adjusted_temps.append(candidate_dict.get('Temperature', row['Temperature']))
 
-    api_output = api_output.copy()
     api_output['score'] = scores
     api_output['adj_kcat'] = adjusted_kcats
     api_output['adj_temp'] = adjusted_temps
@@ -93,15 +100,34 @@ def find_best_match(kcat_dict, api_output, general_criteria) -> Tuple[float, Opt
             tied = tied[tied['organism_score'] == min_tax]
 
     if len(tied) > 1:
-        # Tie-break with lowest kcat
-        min_kcat = tied['adj_kcat'].min()
-        tied = tied[tied['adj_kcat'] == min_kcat]
+        # Tie-break with max kcat value
+        max_kcat = tied['adj_kcat'].max()
+        tied = tied[tied['adj_kcat'] == max_kcat]
 
     # 5. Select best candidate
     best_candidate = tied.iloc[0].to_dict()
     best_candidate['catalytic_enzyme'] = kcat_dict.get('catalytic_enzyme')
     best_score = best_candidate['score']
 
+    # 6. Compute organism_score and id_perc if not present 
+    if best_candidate['organism_score'] == np.inf:
+        if best_candidate.get('Organism') == general_criteria['Organism']:
+            best_candidate['organism_score'] = 0
+        else:
+            tmp_df = pd.DataFrame([best_candidate])
+            taxonomy_score = closest_taxonomy(general_criteria, tmp_df).iloc[0]['organism_score']
+            best_candidate['organism_score'] = taxonomy_score
+
+    if best_candidate['id_perc'] == -1:
+        catalytic = kcat_dict.get('catalytic_enzyme')
+        catalytic_list = str(catalytic).split(";") if catalytic and pd.notna(catalytic) else []
+
+        if best_candidate.get('UniProtKB_AC') in catalytic_list:
+            best_candidate['id_perc'] = 100.0
+        else:
+            tmp_df = pd.DataFrame([best_candidate])
+            best_candidate['id_perc'] = closest_enz(kcat_dict, tmp_df).iloc[0]['id_perc']
+
     return best_score, best_candidate
 
 
@@ -146,7 +172,7 @@ def check_catalytic_enzyme(candidate, kcat_dict):
         catalytic_enzymes = str(kcat_dict['catalytic_enzyme']).split(";")
         if candidate["UniProtKB_AC"] in catalytic_enzymes:
             return 0
-    return 2
+    return 3
 
 
 def check_organism(candidate, general_criteria): 
@@ -222,7 +248,7 @@ def check_temperature(candidate, general_criteria, api_output, min_r2=0.8, expec
         ea, r2 = calculate_ea(api_filtered)
         if r2 >= min_r2 and ea > 0:
             if not (expected_range[0] <= ea <= expected_range[1]):
-                logger.warning(f"{candidate.get('ECNumber')}: Estimated Ea ({ea:.0f} J/mol) is outside the expected range {expected_range} J/mol.")
+                logging.warning(f"{candidate.get('ECNumber')}: Estimated Ea ({ea:.0f} J/mol) is outside the expected range {expected_range} J/mol.")
             # Go Arrhenius
             return 0, True
     
@@ -239,7 +265,7 @@ def check_substrate(entry, kcat_dict=None, candidate=None):
     """
     api = entry.get("db", candidate.get("db") if candidate else None)
 
-    # Normalisation des champs
+    # Normalize names
     entry_subs = entry.get("Substrate", "")
     entry_prods = entry.get("Product", "")
     entry_kegg = entry.get("KeggReactionID")
@@ -252,7 +278,6 @@ def check_substrate(entry, kcat_dict=None, candidate=None):
     model_prods = (kcat_dict or {}).get("products_name", "")
     model_kegg = (kcat_dict or {}).get("rxn_kegg")
 
-    # --- logique identique à avant ---
     if api == "sabio_rk":
         
         entry_kegg = None if pd.isna(entry_kegg) else entry_kegg
@@ -268,15 +293,15 @@ def check_substrate(entry, kcat_dict=None, candidate=None):
         base_subs = model_subs or cand_subs
         if _any_intersection(entry_subs, base_subs):
             return 0
-        return 3
+        return 4
 
     elif api == "brenda":
         base_subs = model_subs or cand_subs
         if _any_intersection(entry_subs, base_subs):
             return 0
-        return 3
+        return 4
 
-    return 3
+    return 4
 
 
 # --- Scoring ---
@@ -288,17 +313,17 @@ def compute_score(kcat_dict, candidate, general_criteria, api_output):
     """
     score = 0
     # Check catalytic enzyme
-    score += check_catalytic_enzyme(candidate, kcat_dict)
+    score += check_catalytic_enzyme(candidate, kcat_dict) # + 0 or 3
     # Check organism
     if score != 0: 
-        score += check_organism(candidate, general_criteria)
+        score += check_organism(candidate, general_criteria) # + 0 or 2  
     # Check variant
-    score += check_variant(candidate) 
+    score += check_variant(candidate) # + 0, 1
     # Check pH
-    score += check_pH(candidate, general_criteria)
+    score += check_pH(candidate, general_criteria) # + 0, 1 or 2
     # Check substrate 
-    score += check_substrate(candidate, kcat_dict)
+    score += check_substrate(candidate, kcat_dict) # + 0 or 4
     # Check temperature 
-    temperature_penalty, arrhenius = check_temperature(candidate, general_criteria, api_output) 
+    temperature_penalty, arrhenius = check_temperature(candidate, general_criteria, api_output) # + 0, 1 or 2
     score += temperature_penalty
     return score, arrhenius
